AutoETS

Struct AutoETS 

pub struct AutoETS { /* private fields */ }
Automatic ETS model selection.

Implementations

Source

impl AutoETS

pub fn new(season_length: usize, spec: String) -> Result<AutoETS, JsValue>

Create a new AutoETS model search instance.

Errors

If the spec string is invalid, this function returns an error.

pub fn fit(&mut self, y: Float64Array) -> Result<(), JsValue>

Search for the best model, fitting it to the data.

The model will be stored on the inner AutoETS instance, after which forecasts can be produced using its predict method.

Errors

If no model can be found, or if any parameters are invalid, this function returns an error.

pub fn predict( &self, horizon: usize, level: Option<f64>, ) -> Result<JsValue, JsValue>

Predict the next horizon values using the best model, optionally including prediction intervals at the specified level.

level should be a float between 0 and 1 representing the confidence level.

Errors

This function will return an error if no model has been fit yet (using AutoETS::fit).